set 2600(name) N/A
set 2600(short) N/A
set 2600(purpose) {convert Google blacklisted words to morse code}
set 2600(invoke) {load-patch 2600}
set 2600(help) {see video: http://vimeo.com/24357958}
set 2600(examples) {}
