set curve-name(name) curve-name
set curve-name(short) cn
set curve-name(purpose) {change name of the selected curve in the current curve editor}
set curve-name(invoke) {curve-name OR cn <name>}
set curve-name(help) {selected curve renamed to name}
set curve-name(examples) {curve-name bezier1 ;# name selected curve to bezier1
cn yet-another-bezier ;# name selected curve to yet-another-bezier}
